scholarly-mcp.tools

Exposed MCP tool implementation handlers for the scholarly server.

Exposed MCP tool implementation handlers for the scholarly server.
raw docstring

build-literature-reviewclj

(build-literature-review {:keys [query]})

Synthesize and group papers for a literature review on a topic.

Synthesize and group papers for a literature review on a topic.
sourceraw docstring

clean-doiclj

(clean-doi doi)

Canonicalize DOI strings for consistent lookup and deduplication.

Canonicalize DOI strings for consistent lookup and deduplication.
sourceraw docstring

clean-titleclj

(clean-title title)

Normalize title strings by converting to lower case and removing non-alphanumeric chars.

Normalize title strings by converting to lower case and removing non-alphanumeric chars.
sourceraw docstring

compare-papersclj

(compare-papers {:keys [dois]})

Compare multiple papers side-by-side using their DOIs.

Compare multiple papers side-by-side using their DOIs.
sourceraw docstring

deduplicate-papersclj

(deduplicate-papers papers)

Deduplicate a collection of paper maps by clean DOI first, then by clean title.

Deduplicate a collection of paper maps by clean DOI first, then by clean title.
sourceraw docstring

export-citationsclj

(export-citations {:keys [dois format]})

Export references for DOIs in BibTeX or RIS format.

Export references for DOIs in BibTeX or RIS format.
sourceraw docstring

extract-keywordsclj

(extract-keywords text max-keywords)

Extract the top keywords from a text snippet using Lucene's StandardAnalyzer.

Extract the top keywords from a text snippet using Lucene's StandardAnalyzer.
sourceraw docstring

find-nature-papers-by-abstractclj

(find-nature-papers-by-abstract {:keys [abstract]})

Find related Nature journal papers based on an abstract snippet.

Find related Nature journal papers based on an abstract snippet.
sourceraw docstring

format-paper-markdownclj

(format-paper-markdown paper)

Format a single paper's metadata into a standard Markdown item.

Format a single paper's metadata into a standard Markdown item.
sourceraw docstring

get-citationsclj

(get-citations {:keys [doi]})

Find papers citing a specific DOI.

Find papers citing a specific DOI.
sourceraw docstring

pending-promisesclj

Atom mapping JSON-RPC message request IDs to promises waiting for client sampling callbacks.

Atom mapping JSON-RPC message request IDs to promises waiting for client sampling callbacks.
sourceraw docstring

retrieve-full-textclj

(retrieve-full-text {:keys [doi]})

Retrieve metadata and link to open access full text (PDF/HTML) if available.

Retrieve metadata and link to open access full text (PDF/HTML) if available.
sourceraw docstring

search-papersclj

(search-papers {:keys [query]})

Search papers by topic across multiple academic indexes (OpenAlex, Semantic Scholar, arXiv, PubMed).

Search papers by topic across multiple academic indexes (OpenAlex, Semantic Scholar, arXiv, PubMed).
sourceraw docstring

summarize-paperclj

(summarize-paper {:keys [doi url] :as kwargs})

Extract and summarize the text of an academic paper using its DOI or direct URL.

Extract and summarize the text of an academic paper using its DOI or direct URL.
sourceraw docstring

summarize-paper-callbackclj

(summarize-paper-callback {:as result})

Callback handler registered with the client to deliver the sampled message result.

Callback handler registered with the client to deliver the sampled message result.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries