scholarly-mcp.tools


build-literature-reviewclj

(build-literature-review {:keys [query]})

Synthesize and group papers for a literature review on a topic.

Synthesize and group papers for a literature review on a topic.
raw docstring

clean-doiclj

(clean-doi doi)

clean-titleclj

(clean-title title)

compare-papersclj

(compare-papers {:keys [dois]})

Compare multiple papers side-by-side using their DOIs.

Compare multiple papers side-by-side using their DOIs.
raw docstring

deduplicate-papersclj

(deduplicate-papers papers)

export-citationsclj

(export-citations {:keys [dois format]})

Export references for DOIs in BibTeX or RIS format.

Export references for DOIs in BibTeX or RIS format.
raw docstring

extract-keywordsclj

(extract-keywords text max-keywords)

Extract the top keywords from a text snippet using Lucene's StandardAnalyzer.

Extract the top keywords from a text snippet using Lucene's StandardAnalyzer.
raw docstring

find-nature-papers-by-abstractclj

(find-nature-papers-by-abstract {:keys [abstract]})

Find related Nature journal papers based on an abstract snippet.

Find related Nature journal papers based on an abstract snippet.
raw docstring

format-paper-markdownclj

(format-paper-markdown paper)

get-citationsclj

(get-citations {:keys [doi]})

Find papers citing a specific DOI.

Find papers citing a specific DOI.
raw docstring

retrieve-full-textclj

(retrieve-full-text {:keys [doi]})

Retrieve metadata and link to open access full text (PDF/HTML) if available.

Retrieve metadata and link to open access full text (PDF/HTML) if available.
raw docstring

search-papersclj

(search-papers {:keys [query]})

Search papers by topic across multiple academic indexes (OpenAlex, Semantic Scholar, arXiv, PubMed).

Search papers by topic across multiple academic indexes (OpenAlex, Semantic Scholar, arXiv, PubMed).
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries